@@ -54,6 +54,7 @@ import java.util.Comparator;
 import java.util.Map;
 import java.util.TimeZone;
 import java.util.UUID;
+import java.util.concurrent.locks.Lock;
 import org.json.JSONObject;
 import com.openexchange.usm.api.contenttypes.ContentType;
 import com.openexchange.usm.api.database.DatabaseAccessException;
@@ -851,6 +852,11 @@ public interface Session {
      */
     OXConnectionInformation getOXConnectionData();
 
+    /**
+     * @return Lock that ensures that only 1 concurrent OX access is performed at a time.
+     */
+    Lock getOXConnectionLock();
+
     /**
      * Retrieves the folder id length limit for this session.
      * 
