@@ -72,6 +72,20 @@ public class ConfigurationProperties {
     public static final String USM_SESSION_STORAGE_TIME_LIMIT_PROPERTY = "com.openexchange.usm.session_storage_time_limit";
 
     public static final int USM_SESSION_STORAGE_TIME_LIMIT_DEFAULT = 60; // 60 days
+    
+    /**
+     * 
+     */
+    public static final String USM_SESSION_CACHE_CHECK_INTERVAL_PROPERTY = "com.openexchange.usm.session_cache_check_interval";
+    
+    public static final int USM_SESSION_CACHE_CHECK_INTERVAL_DEFAULT = 60000; //1 minute
+    
+    /**
+     * 
+     */
+    public static final String USM_SESSION_CACHE_CHECK_INTERVAL_LOG_INFO_PROPERTY = "com.openexchange.usm.session_cache_check_interval_log_info";
+    
+    public static final int USM_SESSION_CACHE_CHECK_INTERVAL_LOG_INFO_DEFAULT = 300000; //5 minutes
 
     /**
      * Specifies a timeout (in seconds) after which USM sessions that are not accessed will be removed from memory. Removed sessions will be
