@@ -48,24 +48,44 @@
  */
 package com.openexchange.usm.contenttypes.contacts.impl;
 
+import java.awt.Color;
 import java.awt.Graphics2D;
 import java.awt.image.BufferedImage;
-import java.io.*;
+import java.io.ByteArrayInputStream;
+import java.io.ByteArrayOutputStream;
+import java.io.IOException;
+import java.io.UnsupportedEncodingException;
 import java.net.URLDecoder;
-import java.util.*;
-
+import java.util.ArrayList;
+import java.util.BitSet;
+import java.util.HashMap;
+import java.util.List;
+import java.util.Map;
 import javax.imageio.ImageIO;
-
 import org.apache.commons.logging.Log;
-import org.json.*;
-
-import com.openexchange.usm.api.contenttypes.*;
-import com.openexchange.usm.api.exceptions.*;
-import com.openexchange.usm.api.session.*;
-import com.openexchange.usm.contenttypes.util.*;
+import org.json.JSONArray;
+import org.json.JSONException;
+import org.json.JSONObject;
+import com.openexchange.usm.api.contenttypes.ContactContentType;
+import com.openexchange.usm.api.contenttypes.ContentTypeField;
+import com.openexchange.usm.api.contenttypes.PictureConversionException;
+import com.openexchange.usm.api.contenttypes.UnsupportedContentOperationException;
+import com.openexchange.usm.api.exceptions.AuthenticationFailedException;
+import com.openexchange.usm.api.exceptions.InternalUSMException;
+import com.openexchange.usm.api.exceptions.OXCommunicationException;
+import com.openexchange.usm.api.exceptions.USMException;
+import com.openexchange.usm.api.session.DataObject;
+import com.openexchange.usm.api.session.Session;
+import com.openexchange.usm.api.session.SyncResult;
+import com.openexchange.usm.contenttypes.util.AbstractTransferHandler;
+import com.openexchange.usm.contenttypes.util.USMContentTypesUtilErrorCodes;
+import com.openexchange.usm.contenttypes.util.UtilConstants;
 import com.openexchange.usm.datatypes.contacts.Image;
 import com.openexchange.usm.datatypes.contacts.ImageDataType;
-import com.openexchange.usm.ox_json.*;
+import com.openexchange.usm.ox_json.JSONResult;
+import com.openexchange.usm.ox_json.JSONResultType;
+import com.openexchange.usm.ox_json.OXJSONAccess;
+import com.openexchange.usm.ox_json.OXResource;
 import com.openexchange.usm.util.Toolkit;
 
 /**
@@ -227,13 +247,15 @@ public class ContactContentTypeTransferHandler extends AbstractTransferHandler {
 		int type = sourceImage.getType();
 		if (type == 0)
 			type = BufferedImage.TYPE_INT_RGB;
-		for (int i = 0; i < 3; i++) {
+		for (int i = 0; i < 6; i++) {
 			int scaledWidth = Math.round(sourceImage.getWidth() * scaleFactor);
 			int scaledHeight = Math.round(sourceImage.getHeight() * scaleFactor);
 			BufferedImage scaledImage = sourceImage;
 			if (scaleFactor < 1.0f) {
-				scaledImage = new BufferedImage(scaledWidth, scaledHeight, type);
+				scaledImage = new BufferedImage(scaledWidth, scaledHeight, BufferedImage.TYPE_INT_RGB);
 				Graphics2D g = scaledImage.createGraphics();
+                g.setColor(Color.WHITE);
+                g.fillRect(0, 0, scaledWidth, scaledHeight);
 				g.drawImage(sourceImage, 0, 0, scaledWidth, scaledHeight, null);
 				g.dispose();
 			}
@@ -249,7 +271,7 @@ public class ContactContentTypeTransferHandler extends AbstractTransferHandler {
 				return null;
 			if (size <= maxSize)
 				return os.toByteArray();
-			scaleFactor *= 0.5f; // estimate was too big, half the size and try again
+			scaleFactor *= 0.7f; // estimate was too big, reduce the size and try again
 		}
 		return null; // one quarter of the estimate is still too big, maybe the limit is too small, return "no image" instead
 	}
