@@ -214,8 +214,8 @@ public abstract class AbstractTransferHandler implements ContentTypeTransferHand
 
 		if (result.getResultType() == JSONResultType.Error) {
 			throw new OXCommunicationException(USMContentTypesUtilErrorCodes.CONFIRM_ERROR_NUMBER5,
-					"Could not confirm appointment " + object.getID() + " for participant: " + participantId, result
-							.getJSONObject());
+					"Could not confirm appointment " + object.getID() + " for participant: " + participantId,
+					result.getJSONObject());
 		} else if (result.getResultType() != JSONResultType.JSONObject) {
 			throw new OXCommunicationException(USMContentTypesUtilErrorCodes.CONFIRM_ERROR_NUMBER6,
 					"Invalid result type returned, expected JSONObject, was " + result.getResultType());
@@ -299,8 +299,8 @@ public abstract class AbstractTransferHandler implements ContentTypeTransferHand
 		String fieldName = field.getFieldName();
 		DataType<?> fieldType = field.getFieldType();
 		try {
-			destination.setFieldContent(fieldName, fieldType.extractFromJSONObject(destination.getSession(), source,
-					fieldName));
+			destination.setFieldContent(fieldName,
+					fieldType.extractFromJSONObject(destination.getSession(), source, fieldName));
 		} catch (JSONException e) {
 			throwInternalUSMException(USMContentTypesUtilErrorCodes.ERROR_READING_DATA_NUMBER5, "reading", destination,
 					fieldName, fieldType, e);
@@ -320,8 +320,8 @@ public abstract class AbstractTransferHandler implements ContentTypeTransferHand
 		DataType<?> fieldType = field.getFieldType();
 		String fieldName = field.getFieldName();
 		try {
-			destination.setFieldContent(fieldName, fieldType.extractFromJSONArray(destination.getSession(), source,
-					index));
+			destination.setFieldContent(fieldName,
+					fieldType.extractFromJSONArray(destination.getSession(), source, index));
 		} catch (JSONException e) {
 			throwInternalUSMException(USMContentTypesUtilErrorCodes.ERROR_READING_DATA_NUMBER4, "reading", destination,
 					fieldName, fieldType, e);
@@ -391,8 +391,8 @@ public abstract class AbstractTransferHandler implements ContentTypeTransferHand
 					}
 				}
 			}
-			throw new ConflictingChangeException(USMContentTypesUtilErrorCodes.DELETE_ERROR, "Deletion failed", result
-					.getJSONObject());
+			throw new ConflictingChangeException(USMContentTypesUtilErrorCodes.DELETE_ERROR, "Deletion failed",
+					result.getJSONObject());
 		}
 	}
 
@@ -539,8 +539,8 @@ public abstract class AbstractTransferHandler implements ContentTypeTransferHand
 			switch (result.getResultType()) {
 				case Error:
 					checkConflictingChange(result.getJSONObject());
-					throw new OXCommunicationException(USMContentTypesUtilErrorCodes.OX_RESULT_ERROR_NUMBER6, result
-							.getJSONObject());
+					throw new OXCommunicationException(USMContentTypesUtilErrorCodes.OX_RESULT_ERROR_NUMBER6,
+							result.getJSONObject());
 				case JSONArray:
 					throw new OXCommunicationException(USMContentTypesUtilErrorCodes.OX_RESULT_ERROR_NUMBER7,
 							"OX server sent array, expected " + expected, result.getJSONArray().toString());
@@ -562,7 +562,7 @@ public abstract class AbstractTransferHandler implements ContentTypeTransferHand
 		if (result.getResultType() == JSONResultType.JSONObject && result.getJSONObject().has("code")) {
 			try {
 				JSONObject errorObject = result.getJSONObject();
-				int category = errorObject.getInt(UtilConstants.CATEGORY);
+				int category = errorObject.optInt(UtilConstants.CATEGORY);
 				String message = errorObject.getString(UtilConstants.ERROR);
 				String code = errorObject.getString(UtilConstants.CODE);
 				JSONArray errorParams = errorObject.getJSONArray(ERROR_PARAMS);
@@ -583,7 +583,7 @@ public abstract class AbstractTransferHandler implements ContentTypeTransferHand
 	protected void checkConflictingChange(JSONObject errorObject) throws ConflictingChangeException,
 			InternalUSMException {
 		try {
-			int category = errorObject.getInt(UtilConstants.CATEGORY);
+			int category = errorObject.optInt(UtilConstants.CATEGORY);
 			String message = errorObject.getString(UtilConstants.ERROR);
 			String code = errorObject.getString(UtilConstants.CODE);
 			if (category == OXErrorConstants.CATEGORY_CONFLICTING_CHANGE
@@ -783,7 +783,7 @@ public abstract class AbstractTransferHandler implements ContentTypeTransferHand
 
 	private boolean isFolderNotExistError(JSONObject errorObject) throws InternalUSMException {
 		try {
-			int category = errorObject.getInt(UtilConstants.CATEGORY);
+			int category = errorObject.optInt(UtilConstants.CATEGORY);
 			String code = errorObject.getString(UtilConstants.CODE);
 			if (category == OXErrorConstants.CATEGORY_CODE_ERROR && OXErrorConstants.IMAP_1002.equals(code)) {
 				return true;
