@@ -48,25 +48,26 @@
  */
 package com.openexchange.usm.connector.commands;
 
-import static com.openexchange.usm.connector.commands.CommandConstants.OBJECTIDS;
-import static com.openexchange.usm.connector.commands.CommandConstants.SESSIONID;
+import static com.openexchange.usm.connector.commands.CommandConstants.*;
 
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpSession;
 
-import org.json.*;
+import org.json.JSONArray;
+import org.json.JSONException;
+import org.json.JSONObject;
 
 import com.openexchange.usm.api.contenttypes.DefaultContentTypes;
 import com.openexchange.usm.api.database.DatabaseAccessException;
-import com.openexchange.usm.api.exceptions.AuthenticationFailedException;
-import com.openexchange.usm.api.exceptions.OXCommunicationException;
 import com.openexchange.usm.api.exceptions.USMException;
 import com.openexchange.usm.api.exceptions.USMSQLException;
 import com.openexchange.usm.api.session.Folder;
 import com.openexchange.usm.api.session.ObjectChanges;
 import com.openexchange.usm.api.session.Session;
 import com.openexchange.usm.api.session.SyncResult;
-import com.openexchange.usm.json.*;
+import com.openexchange.usm.json.ConnectorBundleErrorCodes;
+import com.openexchange.usm.json.USMJSONAPIException;
+import com.openexchange.usm.json.USMJSONServlet;
 import com.openexchange.usm.json.response.ResponseObject;
 import com.openexchange.usm.json.response.ResponseStatusCode;
 import com.openexchange.usm.util.JSONToolkit;
@@ -81,11 +82,11 @@ public class PingHandler extends NormalCommandHandler {
 	private static final String INTERVAL = "interval";
 	private static final String[] REQUIRED_PARAMETERS = { SESSIONID };
 	private static final String[] OPTIONAL_PARAMETERS = { OBJECTIDS };
-	
+
 	private Folder _defaultInbox;
 
-	public PingHandler(USMJSONServlet servlet, HttpSession httpSession, JSONObject parameters, HttpServletRequest request)
-			throws USMJSONAPIException {
+	public PingHandler(USMJSONServlet servlet, HttpSession httpSession, JSONObject parameters,
+			HttpServletRequest request) throws USMJSONAPIException {
 		super(servlet, httpSession, parameters, request);
 		_servlet.newPingRequestArrived();
 	}
@@ -108,7 +109,8 @@ public class PingHandler extends NormalCommandHandler {
 					resultArray.put(getSession().getContextUUID().toString());
 			}
 			if (!hasDefaultInboxChanges(changes) && getDefaultInbox() != null) {
-				if(resultArray == null) resultArray = new JSONArray();
+				if (resultArray == null)
+					resultArray = new JSONArray();
 				long newestTimestamp = getSession().getNewestTimestamp(getDefaultInbox().getID());
 				if (newestTimestamp > 0
 						&& System.currentTimeMillis() - newestTimestamp >= _servlet.getInboxPollingInterval()) {
@@ -119,7 +121,8 @@ public class PingHandler extends NormalCommandHandler {
 				}
 			}
 			JSONObject data = new JSONObject();
-			if(resultArray != null && resultArray.length() > 0) data.put(OBJECTIDS, resultArray);
+			if (resultArray != null && resultArray.length() > 0)
+				data.put(OBJECTIDS, resultArray);
 			data.put(INTERVAL, _servlet.getPingInterval());
 			return new ResponseObject(ResponseStatusCode.SUCCESS, data);
 		} catch (USMException e) {
@@ -129,37 +132,26 @@ public class PingHandler extends NormalCommandHandler {
 					ResponseStatusCode.INTERNAL_ERROR, "waiting for changes interrupted", e);
 		} catch (JSONException e) {
 			throw USMJSONAPIException.createJSONError(ConnectorBundleErrorCodes.PING_JSON_ERROR, e);
-		} 
+		}
 	}
-	
-	private Folder getDefaultInbox() {
+
+	private Folder getDefaultInbox() throws USMException {
 		if (_defaultInbox != null)
 			return _defaultInbox;
-		try {
-			String defaultInboxID = JSONToolkit.getString(getSession().getOXUserConfiguration("modules", "mail",
-					"defaultFolder"), "inbox");
-			if (defaultInboxID == null)
-				return _defaultInbox;
-			_defaultInbox = getSession().getCachedFolder(defaultInboxID);
-		} catch (AuthenticationFailedException e) {
-			_servlet.getJournal().error(
-					"Authentication failed when trying to retrieve the default inbox from the configuration", e);
-		} catch (OXCommunicationException e) {
-			_servlet.getJournal().error(
-					"OXCommunicationException when trying to retrieve the default inbox from the configuration", e);
-		} catch (DatabaseAccessException e) {
-			_servlet.getJournal().error("DBAccessException when trying to read the default inbox from the cache", e);
-		} catch (USMSQLException e) {
-			_servlet.getJournal().error("USMSQLException when trying to read the default inbox from the cache", e);
-		}
+		String defaultInboxID = JSONToolkit.getString(
+				getSession().getOXUserConfiguration("modules", "mail", "defaultFolder"), "inbox");
+		if (defaultInboxID == null)
+			return _defaultInbox;
+		_defaultInbox = getSession().getCachedFolder(defaultInboxID);
 		return _defaultInbox;
 	}
-	
-	private boolean hasDefaultInboxChanges(ObjectChanges changes) {
-		if(getDefaultInbox() == null || changes == null) return false;
-		
+
+	private boolean hasDefaultInboxChanges(ObjectChanges changes) throws USMException {
+		if (getDefaultInbox() == null || changes == null)
+			return false;
+
 		for (String folderID : changes.getContentChangeParentIDs()) {
-			if(folderID.equals(getDefaultInbox().getID()))
+			if (folderID.equals(getDefaultInbox().getID()))
 				return true;
 		}
 		return false;
@@ -169,7 +161,7 @@ public class PingHandler extends NormalCommandHandler {
 		int length = objectUUIDs.length();
 		for (int i = 0; i < length; i++) {
 			String uuid = getString(objectUUIDs, i);
-			if(isContextUUID(uuid))
+			if (isContextUUID(uuid))
 				return true;
 		}
 		return false;
@@ -191,7 +183,7 @@ public class PingHandler extends NormalCommandHandler {
 		if (jsonArray == null)
 			return null;
 		int length = jsonArray.length();
-		String[] stringArray = new String[length - (isContextUUIDRequested(jsonArray)? 1: 0)];
+		String[] stringArray = new String[length - (isContextUUIDRequested(jsonArray) ? 1 : 0)];
 		int j = 0;
 		for (int i = 0; i < length; i++) {
 			String uuid = getString(jsonArray, i);
@@ -202,7 +194,7 @@ public class PingHandler extends NormalCommandHandler {
 		}
 		return stringArray;
 	}
-	
+
 	private JSONArray toUUIDsJSONArray(String[] idsArray) throws DatabaseAccessException, USMSQLException,
 			JSONException {
 		JSONArray result = new JSONArray();
@@ -214,7 +206,7 @@ public class PingHandler extends NormalCommandHandler {
 		}
 		return result;
 	}
-	
+
 	private boolean isOfDefaultContentType(String contentTypeID) {
 		return DefaultContentTypes.FOLDER_ID.equals(contentTypeID)
 				|| DefaultContentTypes.CONTACTS_ID.equals(contentTypeID)
@@ -224,7 +216,6 @@ public class PingHandler extends NormalCommandHandler {
 				|| DefaultContentTypes.GROUPS_ID.equals(contentTypeID)
 				|| DefaultContentTypes.RESOURCES_ID.equals(contentTypeID);
 	}
-	
 
 	@Override
 	protected String[] getOptionalParameters() {
