@@ -132,28 +132,20 @@ public class DataObjectStorage {
     }
 
     public long put(String objectID, long timestamp, DataObjectSet objectSet, long timestampToKeep, SessionImpl session) throws DatabaseAccessException, USMSQLException {
-
         CachedData data = getInternalCacheData(objectID);
-
-        long timestampToReplace = 0L;
-
+        // If SyncState hasn't changed from newest SyncState stored, simply return the timestamp of the newest stored SyncState
         if (!session.getSessionManager().isForceNewSyncKeyOnEmptySync() && !hasStateChanged(data, objectSet, session)) {
             return data.touchNewestTimestamp();
         }
 
         Serializable[][] objects = serializeObjects(objectSet);
-
         boolean shouldKeepTimestamp = timestampToKeep > 0L;
-        boolean makeDeleteAndInsert = timestampToReplace <= 0L;
-
-        long newTS = data.store(timestamp, objects, timestampToKeep, timestampToReplace);
+        long newTS = data.store(timestamp, objects, timestampToKeep);
         long oldTS = data.getTimestamp(shouldKeepTimestamp ? 1 : 0);
         Log journal = getJournal();
 
         if (journal.isDebugEnabled()) {
-            if (!makeDeleteAndInsert) {
-                journal.debug(_session + " Storing in DB cache '" + objectID + "' for " + newTS + ", replacing " + timestampToReplace);
-            } else if (shouldKeepTimestamp)
+            if (shouldKeepTimestamp)
                 journal.debug(_session + " Storing in DB cache '" + objectID + "' for " + newTS + ", keeping " + timestampToKeep + ", removing older than " + oldTS);
             else
                 journal.debug(_session + " Storing in DB cache '" + objectID + "' for " + newTS + ", removing older than " + oldTS);
@@ -162,40 +154,24 @@ public class DataObjectStorage {
         PreparedStatement statement = null;
         try {
             con = _session.getWritableDBConnection();
-            if (!makeDeleteAndInsert) {
-                // make update
-                String updateStatement = "UPDATE USMDataStorage SET syncKey = ? WHERE " + DataObjectStorageSQLStatements.SINGLE_ELEMENT_IDENTIFIER;
-                statement = con.prepareStatement(updateStatement);
-                statement.setLong(1, newTS);
-                statement.setInt(2, _session.getContextId());
-                statement.setInt(3, _session.getSessionId());
-                statement.setString(4, objectID);
-                statement.setLong(5, timestampToReplace);
-                if (statement.executeUpdate() == 0) {
-                    makeDeleteAndInsert = true;
-                }
-            }
-            if (makeDeleteAndInsert) {
-                // make delete/insert
-                String deleteStatement = shouldKeepTimestamp ? (DataObjectStorageSQLStatements.DELETE + DataObjectStorageSQLStatements.UNIQUE_OBJECT_IDENTIFIER + DataObjectStorageSQLStatements.CACHE_DELETE_CONDITION_COMPLEX) : (DataObjectStorageSQLStatements.DELETE + DataObjectStorageSQLStatements.UNIQUE_OBJECT_IDENTIFIER + DataObjectStorageSQLStatements.CACHE_DELETE_CONDITION_SIMPLE);
-                statement = con.prepareStatement(deleteStatement);
-                addObjectIdentifierToStatement(statement, objectID);
-                statement.setLong(NUMBER_OF_OBJECT_ID_FIELDS + 1, newTS);
-                statement.setLong(NUMBER_OF_OBJECT_ID_FIELDS + 2, oldTS);
-                if (shouldKeepTimestamp)
-                    statement.setLong(NUMBER_OF_OBJECT_ID_FIELDS + 3, timestampToKeep);
-                statement.executeUpdate();
-                statement.close();
-
-                statement = con.prepareStatement(DataObjectStorageSQLStatements.FULL_INSERT);
-                String element = writeToString(objects);
-                addObjectIdentifierToStatement(statement, objectID);
-                statement.setLong(NUMBER_OF_OBJECT_ID_FIELDS + 1, newTS);
-                statement.setString(NUMBER_OF_OBJECT_ID_FIELDS + 2, element);
-                if (statement.executeUpdate() != 1)
-                    throw new SQLException("Insert did not produce any results");
-            }
+            // make delete/insert
+            String deleteStatement = shouldKeepTimestamp ? (DataObjectStorageSQLStatements.DELETE + DataObjectStorageSQLStatements.UNIQUE_OBJECT_IDENTIFIER + DataObjectStorageSQLStatements.CACHE_DELETE_CONDITION_COMPLEX) : (DataObjectStorageSQLStatements.DELETE + DataObjectStorageSQLStatements.UNIQUE_OBJECT_IDENTIFIER + DataObjectStorageSQLStatements.CACHE_DELETE_CONDITION_SIMPLE);
+            statement = con.prepareStatement(deleteStatement);
+            addObjectIdentifierToStatement(statement, objectID);
+            statement.setLong(NUMBER_OF_OBJECT_ID_FIELDS + 1, newTS);
+            statement.setLong(NUMBER_OF_OBJECT_ID_FIELDS + 2, oldTS);
+            if (shouldKeepTimestamp)
+                statement.setLong(NUMBER_OF_OBJECT_ID_FIELDS + 3, timestampToKeep);
+            statement.executeUpdate();
+            statement.close();
 
+            statement = con.prepareStatement(DataObjectStorageSQLStatements.FULL_INSERT);
+            String element = writeToString(objects);
+            addObjectIdentifierToStatement(statement, objectID);
+            statement.setLong(NUMBER_OF_OBJECT_ID_FIELDS + 1, newTS);
+            statement.setString(NUMBER_OF_OBJECT_ID_FIELDS + 2, element);
+            if (statement.executeUpdate() != 1)
+                throw new SQLException("Insert did not produce any results");
         } catch (SQLException e) {
             throw new USMSQLException(
                 USMSessionManagementErrorCodes.DATA_STORAGE_ERROR_NUMBER1,
@@ -209,7 +185,7 @@ public class DataObjectStorage {
         return newTS;
     }
 
-    private boolean hasStateChanged(CachedData cachedData, DataObjectSet objects, SessionImpl session) {
+    private static boolean hasStateChanged(CachedData cachedData, DataObjectSet objects, SessionImpl session) {
         long newestTimestamp = cachedData.getNewestTimestamp();
         if (newestTimestamp == 0L) // If we have no sync state yet, we need to store one
             return true;
@@ -226,7 +202,7 @@ public class DataObjectStorage {
         return !objects.isEqualTo(cachedObjects);
     }
 
-    private Serializable[][] serializeObjects(DataObjectSet objects) {
+    private static Serializable[][] serializeObjects(DataObjectSet objects) {
         Serializable[][] data = new Serializable[objects.size()][];
         int i = 0;
         for (DataObject o : objects)
@@ -234,7 +210,7 @@ public class DataObjectStorage {
         return data;
     }
 
-    private DataObject[] deserializeObjects(Serializable[][] values, long timestamp, ContentType contentType, SessionImpl session) {
+    private static DataObject[] deserializeObjects(Serializable[][] values, long timestamp, ContentType contentType, SessionImpl session) {
         DataObject[] result = new DataObject[values.length];
         for (int i = 0; i < result.length; i++) {
             DataObject o = contentType.newDataObject(session);
@@ -407,7 +383,7 @@ public class DataObjectStorage {
         statement.setString(NUMBER_OF_SESSION_ID_FIELDS + 1, objectID);
     }
 
-    private String completeComplexStatement(String prefix, int length) {
+    private static String completeComplexStatement(String prefix, int length) {
         StringBuilder sb = new StringBuilder(prefix);
         for (int i = 0; i < length; i++) {
             if (i > 0)
@@ -495,7 +471,7 @@ public class DataObjectStorage {
         return data;
     }
 
-    private Serializable[][] readFromString(String encodedData) throws DeserializationFailedException {
+    private static Serializable[][] readFromString(String encodedData) throws DeserializationFailedException {
         try {
             ObjectInputStream in = new ObjectInputStream(new GZIPInputStream(new ByteArrayInputStream(Toolkit.decodeBase64(encodedData))));
             return (Serializable[][]) in.readObject();
@@ -517,7 +493,7 @@ public class DataObjectStorage {
         }
     }
 
-    private String writeToString(Serializable[][] objects) {
+    private static String writeToString(Serializable[][] objects) {
         ByteArrayOutputStream baos = new ByteArrayOutputStream();
         try {
             ObjectOutputStream oos = new ObjectOutputStream(new GZIPOutputStream(baos));
