@@ -61,6 +61,8 @@ import java.util.TimeZone;
 import java.util.UUID;
 import java.util.concurrent.ConcurrentHashMap;
 import java.util.concurrent.CopyOnWriteArrayList;
+import java.util.concurrent.locks.Lock;
+import java.util.concurrent.locks.ReentrantLock;
 import org.apache.commons.logging.Log;
 import org.json.JSONException;
 import org.json.JSONObject;
@@ -186,6 +188,8 @@ public class SessionImpl implements Session, Serializable {
 
     private int _directPingResponses = 0;
 
+    private final ReentrantLock _oxLock = new ReentrantLock();
+
     private Map<String, String> _xHeaders = new HashMap<String, String>();
 
     public SessionImpl(SessionManagerImpl sessionManager, String user, String password, String protocol, String device) {
@@ -1360,4 +1364,8 @@ public class SessionImpl implements Session, Serializable {
     public DataObjectStorage getDataObjectCache() {
         return _dataObjectCache;
     }
+
+    public Lock getOXConnectionLock() {
+        return _oxLock;
+    }
 }
