@@ -376,36 +376,38 @@ public class SessionManagerImpl implements SessionManager, OXEventListener {
         return getSession(user, password, protocol, device, null, "127.0.0.1", new HashMap<String, String>());
     }
 
-    public boolean exitsSessionInDB(String user, String protocol, String device) throws USMException {
+    // FIXME This code must be modified to use a more efficient approach. Iterating over all context ids takes way too long for large installations (e.g. 2 mio contexts)
+    // FIXME E.g. first check if USM session exists in memory and determine context id from it. if it doesn't exist in memory, try to login to OX server, and determine
+    // FIXME context id after login was successful. Finally, perform database check only on previously determined context id
+    public boolean existsSessionInDB(String user, String protocol, String device) throws USMException {
         SessionID id = new SessionID(user, protocol, device);
         SessionImpl session = _sessionStorage.getSession(id);
         if (session != null)
             return session.checkProperDBStorage();
-        else {
-            List<Integer> contextIds = _databaseAccess.getAllContextIds();
-            for (Integer contextId : contextIds) {
-                EncapsulatedConnection con = _databaseAccess.getReadOnly(contextId);
-                PreparedStatement statement = null;
-                boolean sessionFound = false;
-                try {
-                    statement = con.prepareStatement("select usmSessionId from USMSession where " + PersistentSessionDataSQLStatements.DEVICE_IN_CONTEXT);
-                    statement.setInt(1, contextId);
-                    statement.setString(2, device);
-                    statement.setString(3, protocol);
-                    ResultSet result = statement.executeQuery();
-                    sessionFound = result.next();
-                } catch (SQLException e) {
-                    String errorMessage = " SQL error while retrieving session from DB";
-                    throw new USMSQLException(USMSessionManagementErrorCodes.PERSISTENT_SESSION_DB_ERROR_2, errorMessage, e);
-                } finally {
-                    Toolkit.close(statement);
-                    Toolkit.close(con);
-                }
-                if (sessionFound)
-                    return true;
+        
+        List<Integer> contextIds = _databaseAccess.getAllContextIds();
+        for (Integer contextId : contextIds) {
+            EncapsulatedConnection con = _databaseAccess.getReadOnly(contextId);
+            PreparedStatement statement = null;
+            boolean sessionFound = false;
+            try {
+                statement = con.prepareStatement("select usmSessionId from USMSession where " + PersistentSessionDataSQLStatements.DEVICE_IN_CONTEXT);
+                statement.setInt(1, contextId);
+                statement.setString(2, device);
+                statement.setString(3, protocol);
+                ResultSet result = statement.executeQuery();
+                sessionFound = result.next();
+            } catch (SQLException e) {
+                String errorMessage = " SQL error while retrieving session from DB";
+                throw new USMSQLException(USMSessionManagementErrorCodes.PERSISTENT_SESSION_DB_ERROR_2, errorMessage, e);
+            } finally {
+                Toolkit.close(statement);
+                Toolkit.close(con);
             }
-            return false;
+            if (sessionFound)
+                return true;
         }
+        return false;
     }
 
     public Session getSession(String user, String password, String protocol, String device, SessionInitializer initializer, String clientIP, Map<String, String> xHeaders) throws USMException {
